from distutils.core import setup

setup(
        name='nester_brnox',
        version='1.0.0',
        py_modules=['nester_brnox'],
        author='hfpython',
        author_email='hfpython@headfirstlabs.com',
        url='http://www.headfirstlabs.com',
        description='A simple printer of nested lists',
    )